pub enum LangTypes {
One(LangType),
Two {
first: LangType,
second: LangType,
},
}Expand description
In some cases, client can use two languages for same LangType. One example is Leptos in Rust, where template and backend have same file extension(‘rs’).
Variants
Implementations